<?php 
// Include the database connection file
require_once 'db_connection.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Get and sanitize the input data
    $name = htmlspecialchars($_POST['name']);
    $slug = htmlspecialchars($_POST['slug']); // Slug entered by the user (optional)
    $description = htmlspecialchars($_POST['description']);
    $price = $_POST['price'];
    
    // Image Upload Process
    if (isset($_FILES['image']) && $_FILES['image']['error'] == 0) {
        $imageName = $_FILES['image']['name'];
        $imageTmpName = $_FILES['image']['tmp_name'];
        $imageSize = $_FILES['image']['size'];
        $imageType = $_FILES['image']['type'];
        
        // Validate image (only allow certain file types)
        $allowedTypes = ['image/jpeg', 'image/png', 'image/gif'];
        if (!in_array($imageType, $allowedTypes)) {
            echo "Error: Only JPG, PNG, and GIF images are allowed.";
            exit;
        }
        
        // Generate a unique name for the image
        $imageExtension = pathinfo($imageName, PATHINFO_EXTENSION);
        $uniqueImageName = uniqid('product_', true) . '.' . $imageExtension;
        $imageDestination = 'product_images/' . $uniqueImageName;

        // Validate file size (max 5MB)
        if ($imageSize > 5 * 1024 * 1024) {
            echo "Error: The image file size is too large (max 5MB).";
            exit;
        }

        // Move the uploaded image to the product_images folder
        if (!move_uploaded_file($imageTmpName, $imageDestination)) {
            echo "Error: Failed to upload the image.";
            exit;
        }
    } else {
        $imageDestination = null; // No image uploaded
    }

    // If no slug is provided, generate one from the product name
    if (empty($slug)) {
        $slug = generateSlug($name);
    }

    // Make sure the slug is unique
    $slug = makeSlugUnique($slug);

    // Prepare the SQL query
    $sql = "INSERT INTO products (name, slug, description, price, image) 
            VALUES (:name, :slug, :description, :price, :image)";
    
    // Prepare the statement
    $stmt = $pdo->prepare($sql);

    // Bind the parameters to the query
    $stmt->bindParam(':name', $name);
    $stmt->bindParam(':slug', $slug);
    $stmt->bindParam(':description', $description);
    $stmt->bindParam(':price', $price);
    $stmt->bindParam(':image', $imageDestination); // Image path in the database

    // Execute the query
    if ($stmt->execute()) {
        echo "Product added successfully!";
    } else {
        echo "Error adding product.";
    }
}

// Function to generate slug
function generateSlug($productName) {
    $slug = strtolower($productName);  // Convert to lowercase
    $slug = preg_replace('/[^a-z0-9]+/', '-', $slug);  // Replace non-alphanumeric characters with hyphens
    $slug = trim($slug, '-');  // Remove any trailing hyphens
    return $slug;
}

// Function to make sure the slug is unique
function makeSlugUnique($slug) {
    global $pdo;
    $stmt = $pdo->prepare("SELECT COUNT(*) FROM products WHERE slug = :slug");
    $stmt->bindParam(':slug', $slug);
    $stmt->execute();

    if ($stmt->fetchColumn() > 0) {
        // If the slug exists, append a number (e.g., blue-widget-1)
        $slug .= '-' . rand(1, 100);
    }

    return $slug;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add Product</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: #f7f7f7;
            margin: 0;
            padding: 0;
        }
        .container {
            width: 50%;
            margin: 50px auto;
            background-color: #fff;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }
        h1 {
            text-align: center;
            color: #333;
        }
        label {
            font-size: 1rem;
            color: #333;
            margin-bottom: 5px;
        }
        input[type="text"], input[type="number"], textarea, input[type="file"] {
            width: 100%;
            padding: 10px;
            margin-bottom: 15px;
            border: 1px solid #ddd;
            border-radius: 4px;
            font-size: 1rem;
        }
        input[type="submit"] {
            background-color: #4CAF50;
            color: white;
            padding: 12px 20px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 1rem;
            width: 100%;
        }
        input[type="submit"]:hover {
            background-color: #45a049;
        }
        .form-group {
            margin-bottom: 15px;
        }
        .error {
            color: red;
            font-size: 0.9rem;
            margin-bottom: 10px;
        }
    </style>
</head>
<body>

<div class="container">
    <h1>Add New Product 0 0 0 00 </h1>

    <!-- Form to add a product -->
    <form action="add_product.php" method="POST" enctype="multipart/form-data">
        <div class="form-group">
            <label for="name">Product Name:</label>
            <input type="text" id="name" name="name" required placeholder="Enter product name">
        </div>

        <div class="form-group">
            <label for="slug">Product Slug (URL friendly):</label>
            <input type="text" id="slug" name="slug" placeholder="Enter a unique product slug">
        </div>

        <div class="form-group">
            <label for="description">Product Description:</label>
            <textarea id="description" name="description" required placeholder="Enter product description"></textarea>
        </div>

        <div class="form-group">
            <label for="price">Price:</label>
            <input type="number" id="price" name="price" required placeholder="Enter product price">
        </div>

        <div class="form-group">
            <label for="image">Product Image:</label>
            <input type="file" id="image" name="image" accept="image/*" required>
        </div>

        <input type="submit" value="Add Product">
    </form>
</div>

</body>
</html>
