<?php
session_start();
// Include the database connection
require_once 'db_connection.php';

// Sanitize and validate the slug from the URL
$slug = $_GET['slug'] ?? '';
if (!preg_match('/^[a-zA-Z0-9-]+$/', $slug)) {
    header('HTTP/1.0 404 Not Found');
    echo "Invalid product slug.";
    exit;
}

// Fetch product details from the database
try {
    $sql = "SELECT * FROM products WHERE slug = :slug";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':slug', $slug, PDO::PARAM_STR);
    $stmt->execute();
    $product = $stmt->fetch();

    if (!$product) {
        header('HTTP/1.0 404 Not Found');
        echo "Product not found.";
        exit;
    }
} catch (PDOException $e) {
    echo "Error fetching product: " . htmlspecialchars($e->getMessage());
    exit;
}

// Handle AJAX requests
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'] ?? '';

    // Add product to cart
    if ($action === 'add_to_cart') {
        $productId = $_POST['id'];
        $productName = $_POST['name'];
        $productPrice = $_POST['price'];
        $productImage = $_POST['image'];

        $_SESSION['cart'][] = [
            'id' => $productId,
            'name' => $productName,
            'price' => $productPrice,
            'image' => $productImage,
        ];

        echo json_encode(['status' => 'success', 'totalItems' => count($_SESSION['cart'])]);
        exit;
    }

    // Clear the cart
    if ($action === 'clear_cart') {
        $_SESSION['cart'] = [];
        echo json_encode(['status' => 'success']);
        exit;
    }

    // Remove an individual item from the cart
    if ($action === 'remove_item') {
        $index = $_POST['index'];
        if (isset($_SESSION['cart'][$index])) {
            unset($_SESSION['cart'][$index]);
            $_SESSION['cart'] = array_values($_SESSION['cart']); // Reindex array
        }
        echo json_encode(['status' => 'success', 'totalItems' => count($_SESSION['cart'])]);
        exit;
    }

    // Get current cart
    if ($action === 'get_cart') {
        echo json_encode($_SESSION['cart'] ?? []);
        exit;
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Product Page</title>
    <!-- Bootstrap CSS -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css">
    <script src="https://code.jquery.com/jquery-3.6.4.min.js"></script>
</head>
<body>
    <?php include "headernav.php"; ?>

    <!-- Product Details Section -->
    <div class="container mt-5">
        <div class="row">
            <!-- Product Image -->
            <div class="col-md-6">
                <img src="<?php echo htmlspecialchars($product['image']); ?>" alt="<?php echo htmlspecialchars($product['name']); ?>" class="img-fluid">
            </div>
            <!-- Product Info -->
            <div class="col-md-6">
                <h1><?php echo htmlspecialchars($product['name']); ?></h1>
                <h3 class="text-primary">₦<?php echo number_format($product['price'], 2); ?></h3>
                <p><?php echo nl2br(htmlspecialchars($product['description'])); ?></p>
                <button class="btn btn-primary add-to-cart-btn" 
                        data-id="<?php echo htmlspecialchars($product['id']); ?>" 
                        data-name="<?php echo htmlspecialchars($product['name']); ?>" 
                        data-price="<?php echo htmlspecialchars($product['price']); ?>" 
                        data-image="<?php echo htmlspecialchars($product['image']); ?>">
                    Add to Cart
                </button>
            </div>
        </div>
    </div>

    <!-- Cart Buttons -->
    <div class="container mt-3">
        <button class="btn btn-success" data-bs-toggle="modal" data-bs-target="#cartModal">View Cart (<span id="cartCount"><?= count($_SESSION['cart'] ?? []) ?></span>)</button>
        <button class="btn btn-danger" id="clearCartBtn">Clear Cart</button>
    </div>

    <!-- Cart Modal -->
    <div class="modal fade" id="cartModal" tabindex="-1" aria-labelledby="cartModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Your Cart</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body" id="cartContent">
                    <!-- Cart content will be loaded here -->
                </div>
            </div>
        </div>
    </div>

    <!-- Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>

    <script>
        function updateCartModal() {
            $.post('', { action: 'get_cart' }, function (response) {
                const cart = JSON.parse(response);
                let content = '';
                if (cart.length === 0) {
                    content = '<p>Your cart is empty.</p>';
                } else {
                    cart.forEach((item, index) => {
                        content += `
                            <div class="d-flex justify-content-between mb-2">
                                <div>
                                    <img src="${item.image}" alt="${item.name}" style="width: 50px; height: 50px; margin-right: 10px;">
                                    ${item.name} - ₦${item.price}
                                </div>
                                <button class="btn btn-danger btn-sm remove-item-btn" data-index="${index}">X</button>
                            </div>`;
                    });
                }
                $('#cartContent').html(content);
            });
        }

        // Add to cart
        $('.add-to-cart-btn').on('click', function () {
            const productData = {
                action: 'add_to_cart',
                id: $(this).data('id'),
                name: $(this).data('name'),
                price: $(this).data('price'),
                image: $(this).data('image'),
            };

            $.post('', productData, function (response) {
                const data = JSON.parse(response);
                if (data.status === 'success') {
                    $('#cartCount').text(data.totalItems);
                }
            });
        });

        // Clear cart
        $('#clearCartBtn').on('click', function () {
            $.post('', { action: 'clear_cart' }, function () {
                $('#cartCount').text(0);
                updateCartModal();
            });
        });

        // Remove item from cart
        $(document).on('click', '.remove-item-btn', function () {
            const index = $(this).data('index');
            $.post('', { action: 'remove_item', index: index }, function (response) {
                const data = JSON.parse(response);
                if (data.status === 'success') {
                    $('#cartCount').text(data.totalItems);
                    updateCartModal();
                }
            });
        });

        // Update cart on modal open
        $('#cartModal').on('show.bs.modal', updateCartModal);
    </script>
</body>
</html>
